@@ -1,15 +1,15 @@
 #define _MCMCGLMMCC_H
 
-extern "C"{
-#include "cs.h"
+/* #include "cs.h" included by MCMCglmm.h */
 #include "MCMCglmm.h" 
-}
-#include <math.h>
+//#include <math.h> already included via R.h
 #include <map>                  
-#include <stdlib.h>    
+//#include <stdlib.h> already included via R.h
 #include <new>            
+/* already included
 #include "R.h" 
 #include "Rmath.h" 
+*/
 #include <iostream>
 #include <limits>
 using namespace std;
